@@ -32,9 +32,9 @@ import java.util.Locale;
 import java.util.Set;
 
 import org.apache.hc.client5.http.classic.methods.HttpGet;
-import org.apache.hc.client5.http.impl.classic.CloseableHttpResponse;
-import org.apache.hc.client5.http.impl.classic.HttpClients;
+import org.apache.hc.client5.http.impl.classic.MinimalHttpClient;
 import org.apache.hc.client5.http.protocol.HttpClientContext;
+import org.apache.hc.client5.testing.sync.extension.TestClientResources;
 import org.apache.hc.core5.http.ClassicHttpRequest;
 import org.apache.hc.core5.http.ClassicHttpResponse;
 import org.apache.hc.core5.http.Header;
@@ -42,17 +42,26 @@ import org.apache.hc.core5.http.HttpException;
 import org.apache.hc.core5.http.HttpHost;
 import org.apache.hc.core5.http.HttpRequest;
 import org.apache.hc.core5.http.HttpStatus;
+import org.apache.hc.core5.http.URIScheme;
 import org.apache.hc.core5.http.io.HttpRequestHandler;
 import org.apache.hc.core5.http.io.entity.EntityUtils;
 import org.apache.hc.core5.http.io.entity.StringEntity;
 import org.apache.hc.core5.http.protocol.HttpContext;
-import org.junit.Assert;
-import org.junit.Test;
+import org.apache.hc.core5.testing.classic.ClassicTestServer;
+import org.apache.hc.core5.util.Timeout;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
 /**
  * Client protocol handling tests.
  */
-public class TestMinimalClientRequestExecution extends LocalServerTestBase {
+public class TestMinimalClientRequestExecution {
+
+    public static final Timeout TIMEOUT = Timeout.ofMinutes(1);
+
+    @RegisterExtension
+    private TestClientResources testResources = new TestClientResources(URIScheme.HTTP, TIMEOUT);
 
     private static class SimpleService implements HttpRequestHandler {
 
@@ -73,45 +82,51 @@ public class TestMinimalClientRequestExecution extends LocalServerTestBase {
 
     @Test
     public void testNonCompliantURIWithContext() throws Exception {
-        this.server.registerHandler("*", new SimpleService());
-        this.httpclient = HttpClients.createMinimal();
-        final HttpHost target = start();
+        final ClassicTestServer server = testResources.startServer(null, null, null);
+        server.registerHandler("*", new SimpleService());
+        final HttpHost target = testResources.targetHost();
+
+        final MinimalHttpClient client = testResources.startMinimalClient();
 
         final HttpClientContext context = HttpClientContext.create();
         for (int i = 0; i < 10; i++) {
             final HttpGet request = new HttpGet("/");
-            try (final CloseableHttpResponse response = this.httpclient.execute(target, request, context)) {
+            client.execute(target, request, context, response -> {
                 EntityUtils.consume(response.getEntity());
-                Assert.assertEquals(HttpStatus.SC_OK, response.getCode());
-            }
+                Assertions.assertEquals(HttpStatus.SC_OK, response.getCode());
+                return null;
+            });
 
             final HttpRequest reqWrapper = context.getRequest();
-            Assert.assertNotNull(reqWrapper);
+            Assertions.assertNotNull(reqWrapper);
 
             final Header[] headers = reqWrapper.getHeaders();
             final Set<String> headerSet = new HashSet<>();
             for (final Header header: headers) {
                 headerSet.add(header.getName().toLowerCase(Locale.ROOT));
             }
-            Assert.assertEquals(3, headerSet.size());
-            Assert.assertTrue(headerSet.contains("connection"));
-            Assert.assertTrue(headerSet.contains("host"));
-            Assert.assertTrue(headerSet.contains("user-agent"));
+            Assertions.assertEquals(3, headerSet.size());
+            Assertions.assertTrue(headerSet.contains("connection"));
+            Assertions.assertTrue(headerSet.contains("host"));
+            Assertions.assertTrue(headerSet.contains("user-agent"));
         }
     }
 
     @Test
     public void testNonCompliantURIWithoutContext() throws Exception {
-        this.server.registerHandler("*", new SimpleService());
-        this.httpclient = HttpClients.createMinimal();
-        final HttpHost target = start();
+        final ClassicTestServer server = testResources.startServer(null, null, null);
+        server.registerHandler("*", new SimpleService());
+        final HttpHost target = testResources.targetHost();
+
+        final MinimalHttpClient client = testResources.startMinimalClient();
 
         for (int i = 0; i < 10; i++) {
             final HttpGet request = new HttpGet("/");
-            try (final CloseableHttpResponse response = this.httpclient.execute(target, request)) {
+            client.execute(target, request, response -> {
                 EntityUtils.consume(response.getEntity());
-                Assert.assertEquals(HttpStatus.SC_OK, response.getCode());
-            }
+                Assertions.assertEquals(HttpStatus.SC_OK, response.getCode());
+                return null;
+            });
         }
     }
 
